@@ -1,13 +1,12 @@
+import collections
 import io
 import os
-import textwrap
-import warnings
-import unittest
 import pathlib
+import textwrap
+import unittest
+import warnings
 
 from typing import Type, Iterable
-from collections.abc import Mapping
-from collections import UserDict
 
 from compat import support, os_helper
 
@@ -19,7 +18,7 @@ def nice_literals(str):
     return str.replace("b'", "'").replace("u'", "'")
 
 
-class SortedDict(UserDict):
+class SortedDict(collections.UserDict):
     def items(self):
         return sorted(self.data.items())
 
@@ -41,13 +40,13 @@ class SortedDict(UserDict):
     __iter__ = iterkeys
 
 
-class CfgParserTestCaseClass(object):
+class CfgParserTestCaseClass:
     allow_no_value = False
     delimiters = ('=', ':')  # type: Iterable[str]
     comment_prefixes = (';', '#')  # type: Iterable[str]
     inline_comment_prefixes = (';', '#')  # type: Iterable[str]
     empty_lines_in_values = True
-    dict_type = configparser._default_dict  # type: Type[Mapping]
+    dict_type = configparser._default_dict  # type: Type[collections.abc.Mapping]
     strict = False
     default_section = configparser.DEFAULTSECT
     interpolation = configparser._UNSET
@@ -1121,9 +1120,11 @@ class ConfigParserTestCaseNoInterpolation(BasicTestCase, unittest.TestCase):
         self.assertMatchesIni(cf)
 
 
-class ConfigParserTestCaseLegacyInterpolation(ConfigParserTestCase, unittest.TestCase):
+class ConfigParserTestCaseLegacyInterpolation(ConfigParserTestCase):
     config_class = configparser.ConfigParser
-    interpolation = configparser.LegacyInterpolation()
+    with warnings.catch_warnings():
+        warnings.simplefilter("ignore", DeprecationWarning)
+        interpolation = configparser.LegacyInterpolation()
 
     def test_set_malformatted_interpolation(self):
         cf = self.fromstring(
@@ -1144,17 +1145,21 @@ class ConfigParserTestCaseLegacyInterpolation(ConfigParserTestCase, unittest.Tes
         self.assertEqual(cf.get("sect", "option2"), "foo%%bar")
 
 
-class ConfigParserTestCaseNonStandardDelimiters(
-    ConfigParserTestCase, unittest.TestCase
-):
+class ConfigParserTestCaseInvalidInterpolationType(unittest.TestCase):
+    def test_error_on_wrong_type_for_interpolation(self):
+        for value in [configparser.ExtendedInterpolation, 42, "a string"]:
+            with self.subTest(value=value):
+                with self.assertRaises(TypeError):
+                    configparser.ConfigParser(interpolation=value)
+
+
+class ConfigParserTestCaseNonStandardDelimiters(ConfigParserTestCase):
     delimiters = (':=', '$')
     comment_prefixes = ('//', '"')
     inline_comment_prefixes = ('//', '"')
 
 
-class ConfigParserTestCaseNonStandardDefaultSection(
-    ConfigParserTestCase, unittest.TestCase
-):
+class ConfigParserTestCaseNonStandardDefaultSection(ConfigParserTestCase):
     default_section = 'general'
 
 
@@ -1607,7 +1612,7 @@ class CopyTestCase(BasicTestCase, unittest.TestCase):
         return cf_copy
 
 
-class FakeFile(object):
+class FakeFile:
     def __init__(self):
         file_path = support.findfile("cfgparser.1")
         with open(file_path, encoding="utf-8") as f:
@@ -1831,6 +1836,14 @@ class CoverageOneHundredTestCase(unittest.TestCase):
         for warning in w:
             self.assertTrue(warning.category is DeprecationWarning)
 
+    def test_legacyinterpolation_deprecation(self):
+        with warnings.catch_warnings(record=True) as w:
+            warnings.simplefilter("always", DeprecationWarning)
+            configparser.LegacyInterpolation()
+        self.assertGreaterEqual(len(w), 1)
+        for warning in w:
+            self.assertIs(warning.category, DeprecationWarning)
+
     def test_sectionproxy_repr(self):
         parser = configparser.ConfigParser()
         parser.read_string(
@@ -2142,7 +2155,7 @@ class ConvertersTestCase(BasicTestCase, unittest.TestCase):
     config_class = configparser.ConfigParser
 
     def newconfig(self, defaults=None):
-        instance = super(ConvertersTestCase, self).newconfig(defaults=defaults)
+        instance = super().newconfig(defaults=defaults)
         instance.converters['list'] = lambda v: [
             e.strip() for e in v.split() if e.strip()
         ]
@@ -2256,7 +2269,7 @@ class BlatantOverrideConvertersTestCase(unittest.TestCase):
             ):
                 if section == option:
                     return True
-                return super(StrangeConfigParser, self).getboolean(
+                return super().getboolean(
                     section, option, raw=raw, vars=vars, fallback=fallback
                 )
 
